.. default-domain:: py
.. currentmodule:: natsort

.. _api:

natsort API
===========

.. toctree::
   :maxdepth: 2

   natsort_keygen.rst
   natsort_key.rst
   natsorted.rst
   versorted.rst
   humansorted.rst
   realsorted.rst
   index_natsorted.rst
   index_versorted.rst
   index_humansorted.rst
   index_realsorted.rst
   order_by_index.rst
   ns_class.rst
